(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13280,        516]*)
(*NotebookOutlinePosition[     14142,        546]*)
(*  CellTagsIndexPosition[     14098,        542]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Read in files with various definitions and the parametrized  expressions for \
the 19-map and an element of the root-selector function.  
NOTE:  Edit `PATH' so that Mathematica can find the files.\
\>", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
<<PATH/Defns;
<<PATH/ThetabarInV;
<<PATH/h19V;\
\>", "Input",
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell["Iteration tools", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
<<PATH/Iter;
iterPrecision=100;\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
beta = -2^2 3^17;
eta = 3^18/2;
gammabar = (282429536481*(39 - I*15^(1/2)))/1024;
alphabar = 8/3*Factor[Expand[(beta*gammabar)^3/eta^8]];\
\>", "Input",
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell["The parametrized sixth-degree form", "Input",
  PageBreakAbove->True,
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[StyleBox[
"FaV =\n\n9*w2^5*(-24*w1 + 19*w2 + 24*w3) +\n \n V^4*w1^4*(-3*w1^2 - 2*w1*w2 \
+ 8*w1*w3 - 5*w3^2) + \n \n V*w2^4*(365*w1^2 - 54*w1*w2 - 171*w2^2 - \
640*w1*w3 - \n 16*w2*w3 + 275*w3^2) + \n \n 5*V^3*(-25*w1^6 + 66*w1^5*w2 - \
33*w1^4*w2^2 + 4*w1^3*w2^3 + \n 112*w1^5*w3 - 224*w1^4*w2*w3 + \
64*w1^3*w2^2*w3 - \n 193*w1^4*w3^2 + 280*w1^3*w2*w3^2 - 30*w1^2*w2^2*w3^2 + \n\
 152*w1^3*w3^3 - 152*w1^2*w2*w3^3 - 43*w1^2*w3^4 + \n 30*w1*w2*w3^4 - \
8*w1*w3^5 + 5*w3^6) +\n  \n V^2*(128*w1^6 - 328*w1^5*w2 + 165*w1^4*w2^2 - \n \
20*w1^3*w2^3 - 365*w1^2*w2^4 + 270*w1*w2^5 - \n 768*w1^5*w3 + 2120*w1^4*w2*w3 \
- 2320*w1^3*w2^2*w3 + \n 2000*w1^2*w2^3*w3 - 360*w1*w2^4*w3 + 1920*w1^4*w3^2 \
- \n 5200*w1^3*w2*w3^2 + 5850*w1^2*w2^2*w3^2 - \n 3800*w1*w2^3*w3^2 + \
675*w2^4*w3^2 - 2560*w1^3*w3^3 + \n 6160*w1^2*w2*w3^3 - 5400*w1*w2^2*w3^3 + \
1800*w2^3*w3^3 + \n 1920*w1^2*w3^4 - 3560*w1*w2*w3^4 + 1705*w2^2*w3^4 - \n \
768*w1*w3^5 + 808*w2*w3^5 + 128*w3^6);",
  PageBreakBelow->True,
  AspectRatioFixed->True,
  FontFamily->"courier",
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}]], "Input",
  PageBreakBelow->True,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["Evaluation-functions for the basic invariants", "Input",
  PageBreakAbove->False,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
FaVEval[v_,{x_,y_,z_}] :=  FaV/.{V->v,w1->x,w2->y,w3->z}

PhiVEval[v_,{x_,y_,z_}] :=
-(1/20250)*
HessianDet3[FaVEval[v,{w1,w2,w3}],{w1,w2,w3}]/.
{w1->x,w2->y,w3->z}

PsiVEval[v_,{x_,y_,z_}] :=
(1/24300)*
AugmentedHessianDet3[
FaVEval[v,{w1,w2,w3}],PhiVEval[v,{w1,w2,w3}],{w1,w2,w3}
]/.
{w1->x,w2->y,w3->z}\
\>", "Input",
  AspectRatioFixed->True],

Cell["Pieces of the root-selector function Jbar", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
ThetabarVEval[v_,{x_,y_,z_}] :=
ThetabarV/.{V->v,w1->x,w2->y,w3->z}

JbarVEval[v_,x_] :=
(alphabar*V^5*(V - 1)^3*ThetabarVEval[v,x]^3)/
FuncEval[PsiVChoose,{w1,w2,w3},x]/.
V->v\
\>", "Input",
  PageBreakAbove->False,
  PageBreakBelow->False,
  AspectRatioFixed->True],

Cell["Evaluation of constants in the root-selection process", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
PsiAt72Point = 3;
QbarAt72Point = I/1728*(3*I + 5*15^(1/2));\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
JbarFac =
Together[ComplexExpand[Apart[
  PsiAt72Point/QbarAt72Point^3
]]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["A 1-parameter Valentiner sextic resolvent", "Input",
  PageBreakAbove->True,
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
ValVbarResolvent6 =
u^6 + I/21600*(3*I + 15^(1/2))*u^4*V + 
(I/3645000000*u*V^2)/15^(1/2) - 
I/583200000*(-4*I + 15^(1/2))*u^2*V^2 + 
((45 - 11*I*15^(1/2))*V^3)/566870400000000

ValVbarResolvent6Eval[v_,x_] := ValVbarResolvent6/.{V->v,u->x}\
\>", "Input",
  AspectRatioFixed->True],

Cell["Select a value of the parameter V", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
VChoose = Random[Complex,100*{-(1+I),1+I},iterPrecision];

N[VChoose]\
\>", "Input",
  PageBreakBelow->False,
  AspectRatioFixed->True],

Cell["Evaluate the 12th and 30th degree forms at VChoose", "Input",
  PageBreakAbove->True,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
FaVChoose = Expand[FaV/.V->VChoose];

PhiVChoose = -(1/20250)*HessianDet3[FaVChoose,{w1,w2,w3}];

PsiVChoose =
(1/24300)*AugmentedHessianDet3[FaVChoose,PhiVChoose,{w1,w2,w3}];\
\>", "Input",
  AspectRatioFixed->True],

Cell["Evaluate the conic-fixing 19-map at VChoose", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
h19VChoose = Expand[h19V/.V->VChoose];

h19VChooseMap[{x_,y_,z_}] := h19VChoose/.{w1->x,w2->y,w3->z};\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The iteration begins\n",
  StyleBox[
  "NOTE:  If you encounter problems with indeterminacy, try\n              \
increasing  \"iterPrecision.\"",
    PageBreakBelow->False,
    AspectRatioFixed->True,
    FontFamily->"Lucida",
    FontWeight->"Plain"]
}], "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
pStart =
Norm1[Table[
  Random[Complex,100*{-(1+I),1+I},iterPrecision]
,{i,3}]];

N[pStart]

NIh19VChoose = Chop[NumIter1[h19VChooseMap,pStart,4]];

N[Take[NIh19VChoose,{-4,-1}]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["The iteration continues (repeat to convergence)", "Input",
  PageBreakAbove->True,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
pCont = NIh19VChoose[[-1]];
 
NIh19VChoose = Chop[NumIter1[h19VChooseMap,pCont,4]];

N[Take[NIh19VChoose,{-4,-1}]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
Compare the last and next-to-next-to-last iterates (looking
for period 2 convergence)\
\>", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["NIh19VChoose[[-1]] - NIh19VChoose[[-3]]", "Input",
  AspectRatioFixed->True],

Cell["\<\
Check that the convergent limit is a 72-point, i.e.,
lies on the 6th and 12th degree curves {F_Y = 0} and
{F_Y = 0}\
\>", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
{N[FaVEval[VChoose,NIh19VChoose[[-1]]]],
 N[FuncEval[PhiVChoose,{w1,w2,w3},NIh19VChoose[[-1]]]]}\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["For sake of comparison, evaluate the 30th degree form ",
    PageBreakAbove->True,
    AspectRatioFixed->True,
    FontFamily->"Lucida",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["\[CapitalPsi]",
    PageBreakAbove->True,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["_Y \nat the limit:",
    PageBreakAbove->True,
    AspectRatioFixed->True,
    FontFamily->"Lucida",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}]
}], "Input",
  PageBreakAbove->True,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
N[FuncEval[
  PsiVChoose,{w1,w2,w3},NIh19VChoose[[-1]]
]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
Evaluate the root-selector function at the iteration's output\
\>", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
JbarVChoose =
Expand[N[
  JbarVEval[VChoose,NIh19VChoose[[-1]]]
,iterPrecision]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["The resolvent corresponding to VChoose", "Input",
  PageBreakAbove->True,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["N[ValVbarResolvent6Eval[VChoose,u]]", "Input",
  AspectRatioFixed->True],

Cell["Compute a candidate root of the resolvent", "Input",
  PageBreakAbove->True,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["ubarVChoose = N[JbarFac JbarVChoose,iterPrecision]", "Input",
  AspectRatioFixed->True],

Cell["Check that the candidate-root is indeed a root", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
N[
 ValVbarResolvent6Eval[VChoose,ubarVChoose]
,iterPrecision]\
\>", "Input",
  AspectRatioFixed->True]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{462, 540},
WindowMargins->{{7, Automatic}, {Automatic, 8}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 436, 13, 112, "Input"],
Cell[2148, 64, 122, 6, 66, "Input",
  PageBreakAbove->False],
Cell[2273, 72, 247, 9, 32, "Input"],
Cell[2523, 83, 82, 4, 48, "Input"],
Cell[2608, 89, 213, 7, 84, "Input",
  PageBreakAbove->False],
Cell[2824, 98, 315, 11, 32, "Input",
  PageBreakAbove->True,
  PageBreakBelow->False],
Cell[3142, 111, 1430, 31, 480, "Input",
  PageBreakBelow->True],
Cell[4575, 144, 302, 10, 32, "Input",
  PageBreakAbove->False],
Cell[4880, 156, 356, 15, 264, "Input"],
Cell[5239, 173, 273, 9, 32, "Input"],
Cell[5515, 184, 277, 11, 138, "Input",
  PageBreakAbove->False,
  PageBreakBelow->False],
Cell[5795, 197, 285, 9, 32, "Input"],
Cell[6083, 208, 111, 4, 48, "Input"],
Cell[6197, 214, 125, 6, 84, "Input"],
Cell[6325, 222, 322, 11, 32, "Input",
  PageBreakAbove->True,
  PageBreakBelow->False],
Cell[6650, 235, 291, 9, 156, "Input"],
Cell[6944, 246, 265, 9, 32, "Input"],
Cell[7212, 257, 145, 6, 84, "Input",
  PageBreakBelow->False],
Cell[7360, 265, 306, 10, 32, "Input",
  PageBreakAbove->True],
Cell[7669, 277, 226, 8, 156, "Input"],
Cell[7898, 287, 275, 9, 32, "Input"],
Cell[8176, 298, 152, 5, 84, "Input"],
Cell[8331, 305, 499, 18, 72, "Input"],
Cell[8833, 325, 229, 12, 192, "Input"],
Cell[9065, 339, 303, 10, 32, "Input",
  PageBreakAbove->True],
Cell[9371, 351, 165, 7, 102, "Input"],
Cell[9539, 360, 325, 12, 72, "Input"],
Cell[9867, 374, 82, 1, 30, "Input"],
Cell[9952, 377, 355, 13, 72, "Input"],
Cell[10310, 392, 147, 4, 48, "Input"],
Cell[10460, 398, 1096, 40, 72, "Input",
  PageBreakAbove->True],
Cell[11559, 440, 108, 5, 66, "Input"],
Cell[11670, 447, 301, 11, 32, "Input"],
Cell[11974, 460, 131, 6, 84, "Input"],
Cell[12108, 468, 294, 10, 32, "Input",
  PageBreakAbove->True],
Cell[12405, 480, 78, 1, 30, "Input"],
Cell[12486, 483, 297, 10, 32, "Input",
  PageBreakAbove->True],
Cell[12786, 495, 93, 1, 30, "Input"],
Cell[12882, 498, 278, 9, 32, "Input"],
Cell[13163, 509, 113, 5, 66, "Input"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

