(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16775,        613]*)
(*NotebookOutlinePosition[     17637,        643]*)
(*  CellTagsIndexPosition[     17593,        639]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Read in files with various definitions and the parametrized  expressions for \
the 19-map and an element of the root-selector function.  
NOTE:  Edit `PATH' so that Mathematica can find the files.\
\>", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
<<PATH/Defns;
<<PATH/GammabarY;
<<PATH/FtauInY;\
\>", "Input",
  AspectRatioFixed->True],

Cell["Iteration tools", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
<<PATH/Iter;
iterPrecision=250;\
\>", "Input",
  AspectRatioFixed->True],

Cell["Some constants that the algorithm uses", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
FtauFac = 1/544195584;
GammabarFac = (39 - I*15^(1/2))/5184;
JbarFac = (6561*(279 + 145*I*15^(1/2)))/2;\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
A polynomial in the parameter Y = (Y1,Y2) that satisfies

              det(tau_z) = F(z)^25*T[Y] \
\>", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
T[Y] =
(Y1 + 20*Y1^2 + 204*Y1^3 + 1094*Y1^4 + 3271*Y1^5 + 
 3078*Y1^6 + 1404*Y1^7 + 18*Y2 + 198*Y1*Y2 + 
 954*Y1^2*Y2 - 198*Y1^3*Y2 - 5508*Y1^4*Y2 - 
 1944*Y1^5*Y2 - 648*Y2^2 - 7776*Y1*Y2^2 - 
 5832*Y1^2*Y2^2 + 11664*Y2^3)/34992;\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[StyleBox["A 2-parameter family of Valentiner resolvents",
  PageBreakAbove->True,
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  PageBreakAbove->True,
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontSize->16],

Cell["\<\
ValYbarResolvent =

-I/90*(-5*I + 15^(1/2))*u^5 + 

u^6 + 

(u^4*(11 + 11*I*15^(1/2) - 
9*Y1 + 3*I*15^(1/2)*Y1))/24300 + (u^3*(100 - 57*I*15^(1/2) + 
270*Y1 - 9*I*15^(1/2)*Y1))/12301875 - 

I/2214337500*u^2*
(-152*I - 17*15^(1/2) - 378*I*Y1 + 72*15^(1/2)*Y1 - 
108*I*Y1^2 + 27*15^(1/2)*Y1^2) + 

(-5 + 3*I*15^(1/2) + 135*Y1 + 
63*I*15^(1/2)*Y1 + 2025*Y1^2 + 81*I*15^(1/2)*Y1^2 + 3645*Y1^3 - 
891*I*15^(1/2)*Y1^3)/2421378056250000 + 

(u*(425 - 103*I*15^(1/2) + 450*Y1 - 1158*I*15^(1/2)*Y1 - 
 675*Y1^2 - 891*I*15^(1/2)*Y1^2 + 7776*I*15^(1/2)*Y2))/
 14946778125000;
 
ValYbarResolventEval[Y_,x_] :=
ValYbarResolvent/.{Y1->Y[[1]],Y2->Y[[2]],u->x}\
\>", "Input",
  AspectRatioFixed->True],

Cell["Select a value of the parameter Y=(Y_1,Y_2)", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell["\<\
YChoose = Table[Random[Complex,1{-(1+I),1+I},iterPrecision],{i,2}];

N[YChoose]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-0.54845793838854`\) - 0.0331973376879491954`\ I, 
      \(-0.995900227970780171`\) - 0.981578163255029068`\ I}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["The polynomial T[Y] evaluated at YChoose",
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontSize->16],

Cell[CellGroupData[{

Cell["\<\
TaYChoose = T[Y]/.{Y1->YChoose[[1]],Y2->YChoose[[2]]};

N[TaYChoose]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(0.631608068793992494`\[InvisibleSpace]\) - 
      0.547786173713756241`\ I\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox[
"The Y-parametrized Valentiner invariants of degrees 6, 12, and 30evaluated \
at YChoose:",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  AspectRatioFixed->True,
  FontSize->16],

Cell["\<\
FaYChoose =
Expand[N[
  FaY/.{Y1->YChoose[[1]],Y2->YChoose[[2]]}
,iterPrecision]];

PhiYChoose = 
N[
-(1/20250)*HessianDet3[FaYChoose,{w1,w2,w3}]
,iterPrecision];

PsiYChoose = 
N[(1/24300)*
AugmentedHessianDet3[FaYChoose,PhiYChoose,{w1,w2,w3}]
,iterPrecision];\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[StyleBox[
"The maps in {w1,w2,w3} associated with the 1-form differentials of F, Phi, \
and Psi evaluated at YChoose:",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  AspectRatioFixed->True,
  FontSize->16],

Cell[CellGroupData[{

Cell["\<\
 DiffFaYChoose = Diff[FaYChoose,{w1,w2,w3}];
DiffPhiYChoose = Diff[PhiYChoose,{w1,w2,w3}];
DiffPsiYChoose = Diff[PsiYChoose,{w1,w2,w3}];\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(General::"spell1" \( : \ \) 
      "Possible spelling error: new symbol name \"\!\(DiffPsiYChoose\)\" is \
similar to existing symbol \"\!\(DiffPhiYChoose\)\"."\)], "Message"]
}, Open  ]],

Cell[TextData[StyleBox[
"Evaluation-function for the  Y-parametrized Valentiner invariants of degree \
45",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  AspectRatioFixed->True,
  FontSize->16],

Cell["\<\
ChiYChooseEval[{x_,y_,z_}] :=
-(1/4860)*Det[
   {DiffFaYChoose,DiffPhiYChoose,DiffPsiYChoose}/.
    {w1->x,w2->y,w3->z}
 ]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[StyleBox["The active ingredient in the root-selector function",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  AspectRatioFixed->True,
  FontSize->16],

Cell["\<\
GammabarYEval[u_,{x_,y_,z_}] :=
GammabarY/.{Y1->u[[1]],Y2->u[[2]],w1->x,w2->y,w3->z}\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[StyleBox["The root-selector function Jbar_Y",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  AspectRatioFixed->True,
  FontSize->16],

Cell["\<\
JbarYEval[u_,x_] :=
((GammabarFac^3/FtauFac^8)*(T[Y]*GammabarYEval[u,x])^3/
FuncEval[PsiYChoose,{w1,w2,w3},x])/.
{Y1->u[[1]],Y2->u[[2]]}\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[StyleBox[
"A degree 64 map that is divisible by the 45th degree invariant Chi",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  AspectRatioFixed->True,
  FontSize->16],

Cell["\<\
f64YChooseMap[{x_,y_,z_}] := 
(
 60466176*TY*(52*PhiY^4 + 17*FY*PhiY*PsiY + 
 82354931712*FY^2*PhiY^3*TY + 7074542592*FY^3*PsiY*TY + 
 9871627788170035200*FY^4*PhiY^2*TY^2 + 
 537209624921382059696455680*FY^6*PhiY*TY^3)*Cross3[aa,bb] -
 
 PsiY*Cross3[aa,cc] + 2*PhiY^2*Cross3[bb,cc] 
 )/.
{TY->TaYChoose,

  FY->FuncEval[FaYChoose,{w1,w2,w3},{x,y,z}],
PhiY->FuncEval[PhiYChoose,{w1,w2,w3},{x,y,z}],
PsiY->FuncEval[PsiYChoose,{w1,w2,w3},{x,y,z}],
 
 aa->FuncEval[DiffFaYChoose,{w1,w2,w3},{x,y,z}],
 bb->FuncEval[DiffPhiYChoose,{w1,w2,w3},{x,y,z}],
 cc->FuncEval[DiffPsiYChoose,{w1,w2,w3},{x,y,z}]}\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[StyleBox[
"A degree 64 map that is also divisible by the 45th degree invariant Chi and \
also preserves all 12 of the conics--this map is projectively equal to \
(h_19)_Y",
  PageBreakAbove->False,
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  PageBreakAbove->False,
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontSize->16],

Cell["\<\
h64YChooseMap[{x_,y_,z_}] :=
(f64Y + 17768930018706063360*ChiY*FY^3*TY^2*Id)/.
 {  TY->TaYChoose,
    FY->FuncEval[FaYChoose,{w1,w2,w3},{x,y,z}],
  ChiY->N[ChiYChooseEval[{x,y,z}],iterPrecision],
    Id->{x,y,z},
  f64Y->f64YChooseMap[{x,y,z}]}\
\>", "Input",
  PageBreakBelow->True,
  AspectRatioFixed->True],

Cell["The iteration", "Input",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[StyleBox["An \"arbitrary\" starting point in CP^2",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  AspectRatioFixed->True,
  FontSize->16],

Cell[CellGroupData[{

Cell["\<\
pStart = 
 Norm1[
  Table[Random[Complex,100{-1-I,1+I},iterPrecision],{i,3}]
 ];

N[pStart]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(1.`\[InvisibleSpace]\) + 0.`\ I, 
      \(-2.45462288692550867`\) - 0.288062561363903402`\ I, 
      \(2.39067779351296705`\[InvisibleSpace]\) - 3.55624980656433065`\ I}
      \)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox[
"The iteration of the map (X_Y)* (h_19)_Y begins\nNOTE:  If you encounter \
problems with indeterminacy, try\n              increasing  \
\"iterPrecision.\"",
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontSize->16],

Cell[CellGroupData[{

Cell["\<\
NIh64Y=Chop[NumIter1[h64YChooseMap,pStart,4]];

N[Take[NIh64Y,{-4,-1}]]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{1.`, \(-0.195725954514100521`\) - 0.116458890642651535`\ I, 
        \(-0.0629408848364865658`\) + 0.0118198289249499953`\ I}, {1.`, 
        \(0.276189358767232828`\[InvisibleSpace]\) + 
          0.046132242621875239`\ I, 
        \(-0.0059969630235185285`\) + 0.00102265915381097638`\ I}, {1.`, 
        \(0.301525269658569117`\[InvisibleSpace]\) - 
          0.0904793764514110243`\ I, 
        \(0.0290342136136675179`\[InvisibleSpace]\) - 
          0.0203541600772499187`\ I}, {0.999999999955942797`, 
        \(0.193734491936677244`\[InvisibleSpace]\) + 
          0.109003825298330525`\ I, 0}}\)], "Output"]
}, Open  ]],

Cell["The iteration continues (repeat to convergence)", "Input",
  PageBreakAbove->True,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontSize->16,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell["\<\
pCont = NIh64Y[[-1]];
 
NIh64Y=NumIter1[h64YChooseMap,pCont,4];

N[Take[NIh64Y,{-4,-1}]]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{\(1.`\[InvisibleSpace]\) - 4.04930617229312161`*^-234\ I, 
        \(0.1281524383313271`\[InvisibleSpace]\) - 0.156536631616460493`\ I, 
        \(0.00622880873578811478`\[InvisibleSpace]\) - 
          0.00172229061790578308`\ I}, {
        \(1.`\[InvisibleSpace]\) + 1.58490879747081425`*^-220\ I, 
        \(0.307195125937897284`\[InvisibleSpace]\) + 
          0.0420477083049486211`\ I, 
        \(0.0191221551024833793`\[InvisibleSpace]\) - 
          0.00329826051317187385`\ I}, {
        \(1.`\[InvisibleSpace]\) + 3.43955937128435618`*^-200\ I, 
        \(0.1281524383313271`\[InvisibleSpace]\) - 0.156536631616460493`\ I, 
        \(0.00622880873578811478`\[InvisibleSpace]\) - 
          0.00172229061790578308`\ I}, {
        \(1.`\[InvisibleSpace]\) + 6.81434403330452109`*^-187\ I, 
        \(0.307195125937897284`\[InvisibleSpace]\) + 
          0.0420477083049486211`\ I, 
        \(0.0191221551024833793`\[InvisibleSpace]\) - 
          0.00329826051317187385`\ I}}\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["Check for period-2 convergence",
  PageBreakAbove->False,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  PageBreakAbove->False,
  AspectRatioFixed->True,
  FontSize->16],

Cell[CellGroupData[{

Cell["N[NIh64Y[[-1]]-NIh64Y[[-3]]]", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-2.11619148810574353`*^-186\) + 6.81434403330452109`*^-187\ I, 
      \(-1.57353400809831223`*^-186\) + 1.40554812076138357`*^-188\ I, 
      \(-8.61476194227696545`*^-188\) + 5.72668231151651863`*^-188\ I}\)], 
  "Output"]
}, Open  ]],

Cell[TextData[StyleBox[
"Check that the iteration's output is a 72-point, i.e., lies on the \
intersection of {F_Y=0} and {Phi_Y=0}",
  PageBreakAbove->True,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  PageBreakAbove->True,
  AspectRatioFixed->True,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \({N[FuncEval[FaYChoose, {w1, w2, w3}, NIh64Y[\([\(-1\)]\)]]], \n\ \ 
      N[FuncEval[PhiYChoose, {w1, w2, w3}, NIh64Y[\([\(-1\)]\)]]]}\)], "Input"],

Cell[BoxData[
    \({\(-1.3639068613187848`*^-181\) - 2.97069510454759608`*^-182\ I, 
      \(-2.9419247419817518`*^-167\) + 1.45831554889762209`*^-167\ I}\)], 
  "Output"]
}, Open  ]],

Cell[TextData[StyleBox[
"For comparison, evaluate the 30th degree invariant at the output",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  AspectRatioFixed->True,
  FontSize->16],

Cell[CellGroupData[{

Cell["N[FuncEval[PsiYChoose,{w1,w2,w3},NIh64Y[[-1]]]]", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(7.54093786296358459`*^49 - 1.81256555103726704`*^49\ I\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["The chosen resolvent ",
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  PageBreakBelow->False,
  AspectRatioFixed->True,
  FontSize->16],

Cell[CellGroupData[{

Cell["N[ValYbarResolventEval[YChoose,u]]", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((\(-7.16363953891883831`*^-14\) + 2.0445813529909067`*^-13\ I)\) + 
      \((1.97461872015983423`*^-9 - 1.9406004628193699`*^-9\ I)\)\ u + 
      \((7.9029192635544625`*^-9 + 8.85395457804736807`*^-8\ I)\)\ u\^2 - 
      \((4.00270674095944301`*^-6 + 0.0000171198143174355461`\ I)\)\ u\^3 + 
      \((\(0.000671680644177301022`\[InvisibleSpace]\) + 
            0.00150325462810909149`\ I)\)\ u\^4 - 
      \((\(0.0555555555555555535`\[InvisibleSpace]\) + 
            0.0430331482911935303`\ I)\)\ u\^5 + u\^6\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox[
"Using the root-selector, compute a candidate solution to the \ngiven \
resolvent",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  AspectRatioFixed->True,
  FontSize->16],

Cell[CellGroupData[{

Cell["\<\
UbarYChoose = 
N[JbarFac*JbarYEval[YChoose,NIh64Y[[-1]]],iterPrecision];

N[UbarYChoose]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(-0.00668742401451681445`\) + 0.00755615371753697395`\ I\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["Check that this candidate solves the resolvent",
  AspectRatioFixed->True,
  FontFamily->"Lucida",
  FontWeight->"Plain"]], "Input",
  AspectRatioFixed->True,
  FontSize->16],

Cell[CellGroupData[{

Cell["N[ValYbarResolventEval[YChoose,UbarYChoose]]", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(-4.73226265620023145`*^-197\) - 4.55114893384593433`*^-195\ I\)], 
  "Output"]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{480, 588},
WindowMargins->{{Automatic, 7}, {Automatic, 5}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 436, 13, 92, "Input"],
Cell[2148, 64, 98, 5, 66, "Input"],
Cell[2249, 71, 247, 9, 32, "Input"],
Cell[2499, 82, 82, 4, 48, "Input"],
Cell[2584, 88, 270, 9, 32, "Input"],
Cell[2857, 99, 154, 5, 66, "Input"],
Cell[3014, 106, 338, 13, 72, "Input"],
Cell[3355, 121, 280, 8, 120, "Input"],
Cell[3638, 131, 295, 9, 32, "Input",
  PageBreakAbove->True,
  PageBreakBelow->False],
Cell[3936, 142, 695, 26, 480, "Input"],
Cell[4634, 170, 275, 9, 32, "Input"],

Cell[CellGroupData[{
Cell[4934, 183, 130, 5, 84, "Input"],
Cell[5067, 190, 148, 2, 29, "Output"]
}, Open  ]],
Cell[5230, 195, 242, 7, 32, "Input",
  PageBreakBelow->False],

Cell[CellGroupData[{
Cell[5497, 206, 119, 5, 66, "Input"],
Cell[5619, 213, 110, 2, 29, "Output"]
}, Open  ]],
Cell[5744, 218, 241, 7, 52, "Input"],
Cell[5988, 227, 312, 16, 264, "Input"],
Cell[6303, 245, 259, 7, 52, "Input"],

Cell[CellGroupData[{
Cell[6587, 256, 187, 5, 66, "Input"],
Cell[6777, 263, 195, 3, 63, "Message"]
}, Open  ]],
Cell[6987, 269, 233, 7, 52, "Input"],
Cell[7223, 278, 173, 7, 102, "Input"],
Cell[7399, 287, 203, 5, 32, "Input"],
Cell[7605, 294, 135, 4, 48, "Input"],
Cell[7743, 300, 185, 5, 32, "Input"],
Cell[7931, 307, 187, 6, 84, "Input"],
Cell[8121, 315, 219, 6, 52, "Input"],
Cell[8343, 323, 647, 20, 354, "Input"],
Cell[8993, 345, 412, 12, 72, "Input",
  PageBreakAbove->False,
  PageBreakBelow->False],
Cell[9408, 359, 319, 10, 138, "Input",
  PageBreakBelow->True],
Cell[9730, 371, 245, 9, 32, "Input"],
Cell[9978, 382, 191, 5, 32, "Input"],

Cell[CellGroupData[{
Cell[10194, 391, 142, 8, 120, "Input"],
Cell[10339, 401, 213, 4, 29, "Output"]
}, Open  ]],
Cell[10567, 408, 358, 10, 72, "Input",
  PageBreakBelow->False],

Cell[CellGroupData[{
Cell[10950, 422, 122, 5, 66, "Input"],
Cell[11075, 429, 638, 11, 86, "Output"]
}, Open  ]],
Cell[11728, 443, 303, 10, 32, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[12056, 457, 139, 7, 102, "Input"],
Cell[12198, 466, 1019, 18, 124, "Output"]
}, Open  ]],
Cell[13232, 487, 232, 7, 32, "Input",
  PageBreakAbove->False],

Cell[CellGroupData[{
Cell[13489, 498, 71, 1, 30, "Input"],
Cell[13563, 501, 246, 4, 67, "Output"]
}, Open  ]],
Cell[13824, 508, 307, 9, 52, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[14156, 521, 167, 2, 50, "Input"],
Cell[14326, 525, 172, 3, 48, "Output"]
}, Open  ]],
Cell[14513, 531, 217, 6, 52, "Input"],

Cell[CellGroupData[{
Cell[14755, 541, 90, 1, 30, "Input"],
Cell[14848, 544, 88, 1, 29, "Output"]
}, Open  ]],
Cell[14951, 548, 223, 7, 32, "Input",
  PageBreakBelow->False],

Cell[CellGroupData[{
Cell[15199, 559, 77, 1, 30, "Input"],
Cell[15279, 562, 546, 8, 124, "Output"]
}, Open  ]],
Cell[15840, 573, 233, 7, 52, "Input"],

Cell[CellGroupData[{
Cell[16098, 584, 139, 6, 84, "Input"],
Cell[16240, 592, 91, 1, 29, "Output"]
}, Open  ]],
Cell[16346, 596, 198, 5, 32, "Input"],

Cell[CellGroupData[{
Cell[16569, 605, 87, 1, 30, "Input"],
Cell[16659, 608, 100, 2, 29, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

